@@ -52,25 +52,23 @@ def makeMd():
             lastTime = line[11:19]
 
             if year != lastYear:
-                print("Year: " + year)
                 mdFile.new_header(level=1, title=year)
                 lastYear = year
 
             if month != lastMonth:
                 monthWorded = monthToWords(month)
-                print("Month: " + monthWorded)
-                mdFile.new_header(level=3, title=monthWorded)
+                mdFile.new_header(level=2, title=monthWorded)
                 lastMonth = month
 
             if date != lastDate:
-                print("Date: " + date)
-                mdFile.new_header(level=4, title=date)
+                mdFile.new_header(level=3, title=date)
                 lastDate = date
         if (firstTwoDigits.isdigit() == False) and (line != "\n"):
             entryContent = lastTime + " - " + line
-            print(entryContent)
             mdFile.new_paragraph(entryContent)
     mdFile.create_md_file()
+    print("md file created")
+    
 def createFile():
     if os.path.exists(outputFileLocation): #If file output.txt exists, remove it. If it doesn't, create it
         os.remove(outputFileLocation)
